import { RpcMessageArgumentTypes, RpcMessageType } from '../protocol/rpc_messages';
import { SecureChannel } from '../protocol/secure_channel';
import { ProviderFrameElement } from './provider_frame_elem';
export declare type RpcMessageHandler<T extends RpcMessageType> = (data: RpcMessageArgumentTypes[T], type: T, ev: MessageEvent) => void;
export interface RelayRequest<T, O> {
    dispatch(options: O): Promise<T>;
}
export declare abstract class BaseRequest<ResultT, OptionsT> implements RelayRequest<ResultT, OptionsT> {
    protected frame: ProviderFrameElement;
    protected channel: SecureChannel;
    id: string;
    private promiseResolver;
    private listenerKeys;
    private timeouts;
    private disposed;
    constructor(frame: ProviderFrameElement, channel: SecureChannel, id?: string);
    abstract dispatch(options: OptionsT): Promise<ResultT>;
    debugLog(message: string): void;
    getPromise(): Promise<ResultT>;
    resolve(response?: ResultT): void;
    reject(reason: Error): void;
    registerHandler<T extends RpcMessageType>(type: T, handler: RpcMessageHandler<T>): void;
    protected clearListeners(): void;
    setAndRegisterTimeout(fn: () => void, timeout: number): void;
    protected clearTimeouts(): void;
    dispose(): void;
}
