export declare const ERROR_TYPES: Readonly<{
    canceled: "canceled";
    clientDisposed: "clientDisposed";
    handshakeFailed: "handshakeFailed";
    invalidCredential: "invalidCredential";
    invalidData: "invalidData";
    iframeError: "iframeError";
    invalidOrigin: "invalidOrigin";
    untrustedOrigin: "untrustedOrigin";
    requestFailed: "requestFailed";
    requestTimeout: "requestTimeout";
    illegalState: "illegalState";
    establishSecureChannelTimeout: "establishSecureChannelTimeout";
    unknownRequest: "unknownRequest";
    apiDisabled: "apiDisabled";
    parentVerifyTimeout: "parentVerifyTimeout";
    parentIsNotRoot: "parentIsNotRoot";
    providerInitFailed: "providerInitFailed";
    unknown: "unknown";
}>;
export declare type ErrorType = keyof typeof ERROR_TYPES;
export interface OpenYoloErrorData {
    code: ErrorType;
    message: string;
    info?: {
        [key: string]: string;
    };
}
export interface OpenYoloExtendedError extends Error {
    data: OpenYoloErrorData;
}
export declare class OpenYoloError {
    static canceled(): OpenYoloExtendedError;
    static clientDisposed(): OpenYoloExtendedError;
    static handshake(reason: string): OpenYoloExtendedError;
    static invalidCredential(): OpenYoloExtendedError;
    static invalidData(): OpenYoloExtendedError;
    static iframe(cause: string): OpenYoloExtendedError;
    static untrustedOrigin(origin: string): OpenYoloExtendedError;
    static requestFailed(message: string): OpenYoloExtendedError;
    static requestTimeout(): OpenYoloExtendedError;
    static illegalStateError(reason: string): OpenYoloExtendedError;
    static establishSecureChannelTimeout(): OpenYoloExtendedError;
    static unknownRequest(requestType: string): OpenYoloExtendedError;
    static apiDisabled(): OpenYoloExtendedError;
    static unknown(): OpenYoloExtendedError;
    static ancestorVerifyTimeout(): OpenYoloExtendedError;
    static parentIsNotRoot(): OpenYoloExtendedError;
    static providerInitFailed(): OpenYoloExtendedError;
    static createError(errorData: OpenYoloErrorData): OpenYoloExtendedError;
    static errorIs<T extends ErrorType>(err: any, code: T): boolean;
}
