/*
 * Copyright 2017 The OpenYOLO for Web Authors. All Rights Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

import {Credential, ProxyLoginResponse} from '../protocol/data';
import {OpenYoloError} from '../protocol/errors';
import {proxyLoginMessage, RPC_MESSAGE_TYPES} from '../protocol/rpc_messages';

import {BaseRequest} from './base_request';

const TIMEOUT_MS = 10000;

/**
 * Handles the proxy login.
 */
export class ProxyLogin extends BaseRequest<ProxyLoginResponse, Credential> {
  /**
   * Starts the Proxy Login flow.
   */
  dispatch(credential: Credential): Promise<ProxyLoginResponse> {
    this.registerHandler(
        RPC_MESSAGE_TYPES.proxyResult, (response: ProxyLoginResponse) => {
          this.resolve(response);
          this.dispose();
        });
    this.setAndRegisterTimeout(() => {
      this.reject(OpenYoloError.requestTimeout());
      this.dispose();
    }, TIMEOUT_MS);

    this.channel.send(proxyLoginMessage(this.id, credential));
    return this.getPromise();
  }
}
